@@ -393,7 +393,6 @@ def test_get_trip_observations_export():
             == "CANCELED"
         )
 
-        breakpoint()
         assert math.isnan(
             df[df["tripId"] == "t_5561911_b_80157_tn_0"].iloc[0].vehicleIds
         )
@@ -981,3 +980,77 @@ def test_get_routes():
             "type": "0",
         },
     ]
+
+
+
+
+
+@httpretty.activate
+def test_get_vehicles():
+    agency = "test_agency"
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    mock_url = client._format_url(client.VEHICLES)
+
+    httpretty.register_uri(
+        httpretty.GET,
+        mock_url,
+        responses=[
+            httpretty.Response(
+                body="""
+                    {
+                      "success": true,
+                      "route": "/real-time/alexandria-dash/vehicles GET",
+                      "data": {
+                        "agencyKey": "alexandria-dash",
+                        "vehicles": [
+                          {
+                            "id": "0402",
+                            "routeId": "KST",
+                            "routeShortName": "KST",
+                            "tripId": "440020",
+                            "headsign": "Market Square/City Hall",
+                            "vehicleType": "3",
+                            "loc": {
+                              "lat": 38.80572,
+                              "lon": -77.05176,
+                              "time": 1743435372,
+                              "speed": 2.2352,
+                              "heading": 99.77457
+                            },
+                            "nextStopId": "574",
+                            "nextStopName": "King St + Patrick St",
+                            "directionId": "1"
+                          },
+                          {
+                            "id": "0523",
+                            "routeId": "102",
+                            "routeShortName": "102",
+                            "tripId": "148020",
+                            "headsign": "Alexandria West-Mark Center Station",
+                            "vehicleType": "3",
+                            "loc": {
+                              "lat": 38.81411,
+                              "lon": -77.07681,
+                              "time": 1743435361,
+                              "speed": 5.36448,
+                              "heading": 275.32855
+                            },
+                            "nextStopId": "117",
+                            "nextStopName": "Janneys Ln + E Taylor Run Pkwy",
+                            "directionId": "0"
+                          }
+                        ]
+                      }
+                    }
+                        
+                    """,
+                status=200,
+            ),
+        ],
+    )
+
+    vehicles = client.get_vehicles()
+    vehicle_ids = [vehicle["id"] for vehicle in vehicles]
+
+    assert vehicle_ids == ["0402", "0523"]
\ No newline at end of file
